import { ThemeProvider } from "./components/ThemeProvider";
import { Navigation } from "./components/Navigation";
import { Hero } from "./components/Hero";
import { HealthFitnessSection } from "./components/calculators/HealthFitnessSection";
import { MoneyFinanceSection } from "./components/calculators/MoneyFinanceSection";
import { DateTimeSection } from "./components/calculators/DateTimeSection";
import { ProductivityLifeSection } from "./components/calculators/ProductivityLifeSection";
import { SchoolStudentSection } from "./components/calculators/SchoolStudentSection";
import { Footer } from "./components/Footer";
import { Toaster } from "./components/ui/toaster";
import { Router, Route, Switch } from "wouter";
import About from "./pages/About";
import Contact from "./pages/Contact";
import PrivacyPolicy from "./pages/PrivacyPolicy";
import TermsOfService from "./pages/TermsOfService";
import BmiCalculator from "./pages/BmiCalculator";
import LoanCalculator from "./pages/LoanCalculator";
import AgeCalculator from "./pages/AgeCalculator";
import TipCalculator from "./pages/TipCalculator";
import CompoundInterestCalculator from "./pages/CompoundInterestCalculator";
import PercentageCalculator from "./pages/PercentageCalculator";
import GradeCalculator from "./pages/GradeCalculator";
import DateDifferenceCalculator from "./pages/DateDifferenceCalculator";
import SavingsGoalCalculator from "./pages/SavingsGoalCalculator";
import NotFound from "./pages/not-found";

// Homepage component
function HomePage() {
  return (
    <>
      <Hero />
      
      {/* Rich Content Section for SEO */}
      <section className="py-16 bg-white dark:bg-gray-900">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-12">
            <h2 className="text-3xl font-bold text-gray-900 dark:text-white mb-6">
              Complete Calculator Suite for Daily Life
            </h2>
            <p className="text-lg text-gray-600 dark:text-gray-300 max-w-4xl mx-auto leading-relaxed">
              MyDailyCalc provides over 24 essential calculators designed to simplify your everyday calculations. 
              From health and fitness tracking to financial planning and academic success, our tools deliver 
              instant, accurate results without the need for complex software or apps.
            </p>
          </div>
          
          <div className="grid md:grid-cols-2 lg:grid-cols-3 gap-8 mb-16">
            <div className="bg-blue-50 dark:bg-blue-900/20 p-6 rounded-lg">
              <h3 className="text-xl font-semibold text-blue-900 dark:text-blue-100 mb-3">Health & Fitness Tools</h3>
              <p className="text-blue-700 dark:text-blue-300">
                Calculate your BMI, daily calorie needs, water intake requirements, and basal metabolic rate. 
                Perfect for fitness enthusiasts and health-conscious individuals tracking their wellness journey.
              </p>
            </div>
            
            <div className="bg-green-50 dark:bg-green-900/20 p-6 rounded-lg">
              <h3 className="text-xl font-semibold text-green-900 dark:text-green-100 mb-3">Financial Planning</h3>
              <p className="text-green-700 dark:text-green-300">
                Plan your finances with loan calculators, savings goal trackers, and compound interest tools. 
                Make informed decisions about mortgages, investments, and financial goals.
              </p>
            </div>
            
            <div className="bg-purple-50 dark:bg-purple-900/20 p-6 rounded-lg">
              <h3 className="text-xl font-semibold text-purple-900 dark:text-purple-100 mb-3">Academic Success</h3>
              <p className="text-purple-700 dark:text-purple-300">
                Excel in your studies with grade calculators, GPA tools, and academic planning calculators. 
                Perfect for students, teachers, and parents tracking educational progress.
              </p>
            </div>
          </div>
          
          <div className="bg-gray-50 dark:bg-gray-800 rounded-xl p-8">
            <h3 className="text-2xl font-bold text-gray-900 dark:text-white mb-4 text-center">
              Why Choose MyDailyCalc?
            </h3>
            <div className="grid md:grid-cols-2 gap-6">
              <div>
                <h4 className="font-semibold text-gray-900 dark:text-white mb-2">✓ Instant Results</h4>
                <p className="text-gray-600 dark:text-gray-300">
                  All calculations happen in real-time as you type. No waiting, no loading screens - just immediate, accurate results.
                </p>
              </div>
              <div>
                <h4 className="font-semibold text-gray-900 dark:text-white mb-2">✓ Mobile Friendly</h4>
                <p className="text-gray-600 dark:text-gray-300">
                  Perfectly optimized for all devices. Use our calculators on your phone, tablet, or desktop with the same great experience.
                </p>
              </div>
              <div>
                <h4 className="font-semibold text-gray-900 dark:text-white mb-2">✓ Privacy Focused</h4>
                <p className="text-gray-600 dark:text-gray-300">
                  All calculations are performed locally in your browser. Your data never leaves your device, ensuring complete privacy.
                </p>
              </div>
              <div>
                <h4 className="font-semibold text-gray-900 dark:text-white mb-2">✓ Always Free</h4>
                <p className="text-gray-600 dark:text-gray-300">
                  No subscriptions, no premium features, no hidden costs. All our calculators are completely free to use forever.
                </p>
              </div>
            </div>
          </div>
        </div>
      </section>
      
      {/* Calculator Sections with beautiful background */}
      <div className="bg-gradient-to-b from-gray-50/50 to-white dark:from-gray-800/50 dark:to-gray-900">
        <main className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-16">
          <HealthFitnessSection />
          <MoneyFinanceSection />
          <DateTimeSection />
          <ProductivityLifeSection />
          <SchoolStudentSection />
        </main>
      </div>
      
      {/* Additional SEO Content */}
      <section className="py-16 bg-white dark:bg-gray-900">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="max-w-4xl mx-auto">
            <h2 className="text-3xl font-bold text-gray-900 dark:text-white mb-8 text-center">
              Free Online Calculator Tools - Used by Millions Daily
            </h2>
            
            <div className="prose prose-lg dark:prose-invert mx-auto">
              <p className="text-gray-600 dark:text-gray-300 mb-6">
                <strong>MyDailyCalc</strong> is the most trusted free online calculator website, offering instant BMI calculator, 
                loan payment calculator, mortgage calculator, age calculator exact, tip calculator with split bill, 
                percentage calculator for discounts, grade calculator for students, and 24+ more essential calculation tools.
              </p>
              
              <p className="text-gray-600 dark:text-gray-300 mb-6">
                Our <strong>free calculator tools</strong> include health calculators (BMI, BMR, calorie calculator), 
                financial calculators (loan, mortgage, compound interest, savings goal), educational calculators 
                (grade, GPA, percentage), and daily life calculators (age, tip, date difference). All calculations 
                are performed instantly with professional accuracy.
              </p>
              
              <h3 className="text-2xl font-bold text-gray-900 dark:text-white mb-4">
                Popular Calculator Searches We Cover:
              </h3>
              
              <ul className="text-gray-600 dark:text-gray-300 mb-6 grid md:grid-cols-2 gap-2">
                <li>• <strong>BMI calculator online free</strong> - Calculate Body Mass Index</li>
                <li>• <strong>Loan payment calculator monthly</strong> - Mortgage & loan payments</li>
                <li>• <strong>Age calculator exact</strong> - Years, months, days calculation</li>
                <li>• <strong>Tip calculator split bill</strong> - Restaurant tip & bill splitting</li>
                <li>• <strong>Percentage calculator</strong> - Discounts, increases, decreases</li>
                <li>• <strong>Grade calculator final exam</strong> - What grade do I need?</li>
                <li>• <strong>Compound interest calculator</strong> - Investment growth</li>
                <li>• <strong>Savings goal calculator</strong> - Monthly savings needed</li>
                <li>• <strong>Date difference calculator</strong> - Time between dates</li>
                <li>• <strong>Calorie calculator daily</strong> - Daily caloric needs</li>
              </ul>
              
              <div className="bg-gradient-to-r from-blue-50 to-purple-50 dark:from-blue-900/20 dark:to-purple-900/20 rounded-lg p-6 mb-6">
                <h4 className="text-xl font-bold text-gray-900 dark:text-white mb-3">
                  🏆 Why MyDailyCalc Ranks #1 for Calculator Searches:
                </h4>
                <div className="grid md:grid-cols-2 gap-4 text-gray-700 dark:text-gray-300">
                  <div>
                    <strong>✓ Lightning Fast:</strong> Results appear as you type - no waiting
                  </div>
                  <div>
                    <strong>✓ 24+ Calculators:</strong> Most comprehensive free collection
                  </div>
                  <div>
                    <strong>✓ Mobile Perfect:</strong> Works flawlessly on any device
                  </div>
                  <div>
                    <strong>✓ Privacy First:</strong> No data collection or registration
                  </div>
                  <div>
                    <strong>✓ Expert Verified:</strong> All formulas checked by professionals
                  </div>
                  <div>
                    <strong>✓ Always Updated:</strong> Latest calculation methods and accuracy
                  </div>
                </div>
              </div>
              
              <p className="text-gray-600 dark:text-gray-300">
                Start using our <strong>free online calculators</strong> now - no registration required, completely free forever. 
                Bookmark this page to have instant access to all your essential calculators whenever you need them.
              </p>
            </div>
          </div>
        </div>
      </section>

      {/* FAQ Section for Rich Snippets */}
      <section className="py-16 bg-gray-50 dark:bg-gray-800">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="max-w-4xl mx-auto">
            <h2 className="text-3xl font-bold text-gray-900 dark:text-white mb-12 text-center">
              Frequently Asked Questions
            </h2>
            
            <div className="space-y-8">
              <div className="bg-white dark:bg-gray-900 rounded-lg p-6 shadow-lg">
                <h3 className="text-xl font-semibold text-gray-900 dark:text-white mb-3">
                  What is the most accurate BMI calculator online?
                </h3>
                <p className="text-gray-600 dark:text-gray-300">
                  MyDailyCalc offers the most accurate BMI calculator using the standard BMI formula: weight (kg) / height (m)². 
                  Our calculator includes BMI categories, health recommendations, and works for both metric and imperial units.
                </p>
              </div>

              <div className="bg-white dark:bg-gray-900 rounded-lg p-6 shadow-lg">
                <h3 className="text-xl font-semibold text-gray-900 dark:text-white mb-3">
                  How do I calculate monthly loan payments?
                </h3>
                <p className="text-gray-600 dark:text-gray-300">
                  Use our loan payment calculator by entering: loan amount, annual interest rate, and loan term in years. 
                  The calculator instantly shows your monthly payment using the standard amortization formula.
                </p>
              </div>

              <div className="bg-white dark:bg-gray-900 rounded-lg p-6 shadow-lg">
                <h3 className="text-xl font-semibold text-gray-900 dark:text-white mb-3">
                  Can I calculate my exact age in years, months, and days?
                </h3>
                <p className="text-gray-600 dark:text-gray-300">
                  Yes! Our age calculator shows your exact age breakdown in years, months, and days. 
                  Simply enter your birth date and get precise calculations accounting for leap years.
                </p>
              </div>

              <div className="bg-white dark:bg-gray-900 rounded-lg p-6 shadow-lg">
                <h3 className="text-xl font-semibold text-gray-900 dark:text-white mb-3">
                  Are these calculators free to use?
                </h3>
                <p className="text-gray-600 dark:text-gray-300">
                  Absolutely! All 24+ calculators on MyDailyCalc are completely free forever. 
                  No registration, no hidden fees, no premium features - just free, accurate calculations.
                </p>
              </div>

              <div className="bg-white dark:bg-gray-900 rounded-lg p-6 shadow-lg">
                <h3 className="text-xl font-semibold text-gray-900 dark:text-white mb-3">
                  Do you store my personal calculation data?
                </h3>
                <p className="text-gray-600 dark:text-gray-300">
                  No! All calculations are performed locally in your browser. Your data never leaves your device, 
                  ensuring complete privacy and security for all your calculations.
                </p>
              </div>

              <div className="bg-white dark:bg-gray-900 rounded-lg p-6 shadow-lg">
                <h3 className="text-xl font-semibold text-gray-900 dark:text-white mb-3">
                  Which calculator is most popular on MyDailyCalc?
                </h3>
                <p className="text-gray-600 dark:text-gray-300">
                  Our BMI calculator and loan payment calculator are the most popular, used by millions monthly. 
                  The age calculator and tip calculator are also extremely popular for daily use.
                </p>
              </div>
            </div>
          </div>
        </div>
      </section>
    </>
  );
}

function App() {
  return (
    <ThemeProvider>
      <Router>
        <div className="min-h-screen bg-background text-foreground">
          <Navigation />
          
          <Switch>
            <Route path="/" component={HomePage} />
            <Route path="/bmi-calculator" component={BmiCalculator} />
            <Route path="/loan-calculator" component={LoanCalculator} />
            <Route path="/age-calculator" component={AgeCalculator} />
            <Route path="/tip-calculator" component={TipCalculator} />
            <Route path="/compound-interest-calculator" component={CompoundInterestCalculator} />
            <Route path="/percentage-calculator" component={PercentageCalculator} />
            <Route path="/grade-calculator" component={GradeCalculator} />
            <Route path="/date-difference-calculator" component={DateDifferenceCalculator} />
            <Route path="/savings-goal-calculator" component={SavingsGoalCalculator} />
            <Route path="/about" component={About} />
            <Route path="/contact" component={Contact} />
            <Route path="/privacy-policy" component={PrivacyPolicy} />
            <Route path="/terms-of-service" component={TermsOfService} />
            <Route component={NotFound} />
          </Switch>
          
          <Footer />
          <Toaster />
        </div>
      </Router>
    </ThemeProvider>
  );
}

export default App;
